var searchData=
[
  ['length_0',['Length',['../classopencc_1_1_u_t_f8_util.html#ac0642244a71d77d3e79829a7952f9b86',1,'opencc::UTF8Util']]],
  ['lexicon_1',['Lexicon',['../classopencc_1_1_lexicon.html',1,'opencc']]],
  ['library_20第三方庫_2',['Third Party Library 第三方庫',['../index.html#autotoc_md26',1,'']]],
  ['license_20許可協議_3',['License 許可協議',['../index.html#autotoc_md25',1,'']]],
  ['line_4',['Command Line',['../index.html#autotoc_md12',1,'']]],
  ['links_20相關鏈接_5',['Links 相關鏈接',['../index.html#autotoc_md28',1,'']]],
  ['linux_20mac_20os_20x_6',['Linux Mac OS X',['../index.html#autotoc_md18',1,'Linux &amp; Mac OS X'],['../index.html#autotoc_md21',1,'Linux &amp; Mac OS X']]]
];
